@@ -1,6 +1,7 @@
 import datetime
 
 from django import template
+
 from commons.python import formatter, utils
 
 register = template.Library()
@@ -34,3 +35,13 @@ def true_if_none(value):
 @register.filter(name='to_boolean')
 def to_boolean(value):
     return utils.to_boolean(value)
+
+
+@register.filter(name='to_hour_minute')
+def to_hour_minute(value) -> str:
+    return formatter.to_time(value, '%H:%M')
+
+
+@register.filter(name='formatter_time')
+def formatter_time(time_instance):
+    return formatter.format_time(time_instance, '%H:%M')
